@@ -1,4 +1,4 @@
-/* Stereograph 0.13, 31/03/2000;
+/* Stereograph 0.14, 08/04/2000;
  * renderer, stereographer's engine;
  * Copyright (c) 2000 by Fabian Januszewski <fabian.linux@januszewski.de>
  *
@@ -112,7 +112,7 @@ int RenderLine(int *base_data, int *texture_data, int *stereo_data)
 
 	if(Param.AA - 1)
 	{
-   		if(Param.Zoom)
+   		if(Param.Zoom - 1)
 			return ZoomAAScan(stereo_data, texture_data);
 		else
 			return AAScan(stereo_data, texture_data);
@@ -200,7 +200,7 @@ int NormalScan(int *stereo_data, int *texture_data)
 		if( ((int) z < Base.Width) && ((int) z >= 0))
 			stereo_data[scanx] = stereo_data[(int) z];
 	}
-	for (scanx = Renderer.startx - 1; scanx >= 0; scanx--)
+	for (scanx = Renderer.startx; scanx >= 0; scanx--)
 	{
 		z = scanx + Renderer.left_change_map[scanx];
 		/* 'cause of problems without the round function - internal round, it's a cut - it is NOT symmetric */
@@ -232,6 +232,9 @@ int AAScan(int *stereo_data, int *texture_data)
 		if ((z >= Renderer.startx) && (z < Base.Width))
 			for (a = 0; a < Renderer.nfactor; a++)
 				Renderer.scanline[(scanx * Renderer.nfactor) + a] = Renderer.scanline[((int) (z * Renderer.nfactor) + a)];
+		else if (z > (Renderer.startx - 1) && (z < Renderer.startx))
+        		for (a = (-z + (float) Renderer.startx) * Renderer.nfactor; a < Renderer.nfactor; a++)
+				Renderer.scanline[(scanx * Renderer.nfactor) + a] = Renderer.scanline[((int) (z * Renderer.nfactor) + a)];
 	}
 	for (scanx = Renderer.startx + Texture.Width; scanx < Base.Width; scanx++)
 	{
@@ -288,14 +291,17 @@ int ZoomScan(int *stereo_data, int *texture_data)
 		z = scanx + Renderer.right_change_map[scanx];
 		if ((z >= Renderer.startx) && (z < Base.Width))
 			for (a = 0; a < Renderer.nfactor; a++)
-				stereo_data[(scanx * Renderer.nfactor) + a] = stereo_data[(int) (z * Renderer.nzoom) + a];
+				stereo_data[(scanx * Renderer.nfactor) + a] = stereo_data[(int) (z * Renderer.nfactor) + a];
+		else if ((z > (Renderer.startx - 1)) && (z < Renderer.startx))
+        		for (a = (-z + (float) Renderer.startx) * Renderer.nfactor; a < Renderer.nfactor; a++)
+				stereo_data[(scanx * Renderer.nfactor) + a] = stereo_data[((int) (z * Renderer.nfactor) + a)];
 	}
 	for (scanx = Renderer.startx + Texture.Width; scanx < Base.Width; scanx++)
 	{
 		z = scanx + Renderer.right_change_map[scanx];
 		if((z < Base.Width) && (z >= 0))
 			for (a = 0; a < Renderer.nfactor; a++)
-				stereo_data[(scanx * Renderer.nzoom) + a] = stereo_data[(int) (z * Renderer.nzoom) + a];
+				stereo_data[(scanx * Renderer.nfactor) + a] = stereo_data[(int) (z * Renderer.nfactor) + a];
 	}
 
 	for (scanx = Renderer.startx; scanx >= 0; scanx--)
@@ -307,7 +313,7 @@ int ZoomScan(int *stereo_data, int *texture_data)
 			if (z != ((int) z))
 				z++;
 			for (a = 0; a < Renderer.nfactor; a++)
-				stereo_data[(scanx * Renderer.nzoom) + a] = stereo_data[(int) z + a];  /* attention : z is was already multiplied above!!! */
+				stereo_data[(scanx * Renderer.nfactor) + a] = stereo_data[(int) z + a];  /* attention : z is was already multiplied above!!! */
 		}
 	}
 
@@ -339,6 +345,9 @@ int ZoomAAScan(int *stereo_data, int *texture_data)
 		if ((z >= Renderer.startx) && (z < Base.Width))
 			for (a = 0; a < Renderer.nfactor; a++)
 				Renderer.scanline[(scanx * Renderer.nfactor) + a] = Renderer.scanline[(int) (z * Renderer.nfactor) + a];
+		else if (z > (Renderer.startx - 1) && (z < Renderer.startx))
+        		for (a = (-z + (float) Renderer.startx) * Renderer.nfactor; a < Renderer.nfactor; a++)
+				Renderer.scanline[(scanx * Renderer.nfactor) + a] = Renderer.scanline[((int) (z * Renderer.nfactor) + a)];
 	}
 	for (scanx = Renderer.startx + Texture.Width; scanx < Base.Width; scanx++)
 	{
